# winsay
Say command in windows

![](https://raw.githubusercontent.com/sukhbinder/winsay/master/img/youtube.png)


### Back Story

Read the backstory for this project [here](https://sukhbinder.wordpress.com/2020/09/30/winsay/)

# Install
pip install winsay


# Demo


[![Check a demo](https://raw.githubusercontent.com/sukhbinder/winsay/master/img/youtube.png)](https://youtu.be/dZaV5MtG3n4)


